package com.smaato.soma.mopubcustomevent;

import android.content.Context;

import com.mopub.mobileads.CustomEventBanner;
import com.mopub.mobileads.MoPubErrorCode;
import com.smaato.soma.AdDownloaderInterface;
import com.smaato.soma.AdListenerInterface;
import com.smaato.soma.BannerStateListener;
import com.smaato.soma.BannerView;
import com.smaato.soma.BaseView;
import com.smaato.soma.CrashReportTemplate;
import com.smaato.soma.ReceivedBannerInterface;
import com.smaato.soma.bannerutilities.constant.BannerStatus;
import com.smaato.soma.debug.DebugCategory;
import com.smaato.soma.debug.Debugger;
import com.smaato.soma.debug.LogMessage;
import com.smaato.soma.exception.ClosingLandingPageFailed;

import java.util.Map;

/**
 * Example of MoPub Smaato Banner mediation adapter.
 *
 * Updated in Smaato SDK 5.0.7 version release
 * @author Palani Soundararajan
 *
 */

public class SomaMopubAdapter extends CustomEventBanner {

    private static BannerView mBanner;

    private static String TAG = "SmaatoMopubBanner";

    /*
    * (non-Javadoc)
    * @see
    * com.mopub.mobileads.CustomEventBanner#loadBanner(android.content.Context,
    * com.mopub.mobileads.CustomEventBanner.CustomEventBannerListener,
    * java.util.Map, java.util.Map) */
    @Override
    public void loadBanner(Context context,
                           final CustomEventBannerListener customEventBannerListener, Map<String, Object> localExtras,
                           Map<String, String> serverExtras) {
        try {
            if (mBanner == null) {

                //Debugger.setDebugMode(Debugger.Level_3);
                mBanner = new BannerView(context);
                mBanner.addAdListener(new AdListenerInterface() {
                    @Override
                    public void onReceiveAd(AdDownloaderInterface arg0,
                                            final ReceivedBannerInterface arg1) {

                        new CrashReportTemplate<Void>() {
                            @Override
                            public Void process() throws Exception {

                                if (arg1.getStatus() == BannerStatus.ERROR) {
                                    printDebugLogs("NO_FILL", DebugCategory.DEBUG);
                                    customEventBannerListener.onBannerFailed(MoPubErrorCode.NO_FILL);
                                } else {
                                    printDebugLogs("Ad available", DebugCategory.DEBUG);
                                    customEventBannerListener.onBannerLoaded(mBanner);
                                }

                                return null;
                            }
                        }.execute();

                    }
                });
                mBanner.setBannerStateListener(new BannerStateListener() {
                    @Override
                    public void onWillOpenLandingPage(BaseView arg0) {
                        printDebugLogs("Banner Clicked", DebugCategory.DEBUG);
                    }

                    @Override
                    public void onWillCloseLandingPage(BaseView arg0) throws ClosingLandingPageFailed {
                        new CrashReportTemplate<Void>() {
                            @Override
                            public Void process() throws Exception {
                                mBanner.asyncLoadNewBanner();
                                printDebugLogs("Banner closed", DebugCategory.DEBUG);
                                return null;
                            }
                        }.execute();
                    }
                });
            }
            int publisherId = Integer.parseInt(serverExtras.get("publisherId"));
            int adSpaceId = Integer.parseInt(serverExtras.get("adSpaceId"));
            mBanner.getAdSettings().setPublisherId(publisherId);
            mBanner.getAdSettings().setAdspaceId(adSpaceId);
            mBanner.asyncLoadNewBanner();
        } catch (RuntimeException e) {
            e.printStackTrace();
            printDebugLogs("Failed to load banner",DebugCategory.ERROR);
        } catch (Exception e) {
            e.printStackTrace();
        }
    } /*
* (non-Javadoc)
* @see com.mopub.mobileads.CustomEventBanner#onInvalidate() */

    @Override
    public void onInvalidate() {
        // clear for memory
    }

    public void printDebugLogs(String str, DebugCategory debugCategory){
        Debugger.showLog(new LogMessage(TAG,
                str,
                Debugger.Level_1,
                debugCategory));
    }

}